summaryrefslogtreecommitdiffstats
path: root/server/src/com/vaadin/ui/UI.java
diff options
context:
space:
mode:
Diffstat (limited to 'server/src/com/vaadin/ui/UI.java')
-rw-r--r--server/src/com/vaadin/ui/UI.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/server/src/com/vaadin/ui/UI.java b/server/src/com/vaadin/ui/UI.java
index 2b2e773601..5fbd654dcf 100644
--- a/server/src/com/vaadin/ui/UI.java
+++ b/server/src/com/vaadin/ui/UI.java
@@ -668,10 +668,10 @@ public abstract class UI extends AbstractSingleComponentContainer implements
* @param request
* the request that caused this UI to be reloaded
*/
- public void doReinit(VaadinRequest request) {
+ public void doRefresh(VaadinRequest request) {
// This is a horrible hack. We want to have the most recent location and
// browser window size available in reinit(), but we want to call
// listeners, if any, only after reinit(). So we momentarily assign the
// old values back before setting the new values again to ensure the
// events are properly fired.
@@ -683,7 +683,7 @@ public abstract class UI extends AbstractSingleComponentContainer implements
page.init(request);
- reinit(request);
+ refresh(request);
URI newLocation = page.getLocation();
int newWidth = page.getBrowserWindowWidth();
@@ -709,7 +709,7 @@ public abstract class UI extends AbstractSingleComponentContainer implements
* @param request
* the request that caused this UI to be reloaded
*/
- protected void reinit(VaadinRequest request) {
+ protected void refresh(VaadinRequest request) {
}
/**
@@ -668,10 +668,10 @@ public abstract class UI extends AbstractSingleComponentContainer implements
// This is a horrible hack. We want to have the most recent location and
- // browser window size available in reinit(), but we want to call
- // listeners, if any, only after reinit(). So we momentarily assign the
+ // browser window size available in refresh(), but we want to call
+ // listeners, if any, only after refresh(). So we momentarily assign the
// old values back before setting the new values again to ensure the
// events are properly fired.